Stan Math Library: stan::VectorBuilderHelper< T1, used, is_vec > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Public Member Functions | List of all members
stan::VectorBuilderHelper< T1, used, is_vec > Class Template Reference

VectorBuilder allocates type T1 values to be used as intermediate values. More...

`#include <VectorBuilderHelper.hpp>`

## Public Types
typedef T1 | type

## Public Member Functions
| VectorBuilderHelper (size_t)
T1 & | operator[] (size_t)
type & | data ()

## Detailed Description

### template<typename T1, bool used, bool is_vec>
class stan::VectorBuilderHelper< T1, used, is_vec >

VectorBuilder allocates type T1 values to be used as intermediate values.

There are 2 template parameters:

- used: boolean variable indicating whether this instance is used. If this is false, there is no storage allocated and operator[] throws.
- is_vec: boolean variable indicating whether this instance should allocate a vector, if it is used. If this is false, the instance will only allocate a single double value. If this is true, it will allocate the number requested. Note that this is calculated based on template parameters T2 through T7.

These values are mutable.

Definition at line 25 of file VectorBuilderHelper.hpp.

## Member Typedef Documentation

template<typename T1, bool used, bool is_vec>

typedef T1 stan::VectorBuilderHelper< T1, used, is_vec >::type

Definition at line 33 of file VectorBuilderHelper.hpp.

## Constructor & Destructor Documentation

template<typename T1, bool used, bool is_vec>

stan::VectorBuilderHelper< T1, used, is_vec >::VectorBuilderHelper | ( | size_t |  | ) |
| inlineexplicit

Definition at line 27 of file VectorBuilderHelper.hpp.

## Member Function Documentation

template<typename T1, bool used, bool is_vec>

type& stan::VectorBuilderHelper< T1, used, is_vec >::data | ( |  | ) |
| inline

Definition at line 35 of file VectorBuilderHelper.hpp.

template<typename T1, bool used, bool is_vec>

T1& stan::VectorBuilderHelper< T1, used, is_vec >::operator[] | ( | size_t |  | ) |
| inline

Definition at line 29 of file VectorBuilderHelper.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/scal/meta/VectorBuilderHelper.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.